import csv
import matplotlib.pyplot as plt
import numpy as np
from math import sqrt
 
########################################################################
###        IMPORTATION DES DONNEES DEPUIS LE FICHIER EXCEL           ###
### le fichier excel doit être dans le même dossier que ce programme ###
########################################################################

# importation du fichier et détermination des nombres de lignes et de colonnes

fichier=open("nom.txt",'r')
donnees = list(csv.reader(fichier,delimiter=';'))
fichier.close()

# Création des listes t, X et Y de dates, d'abscisses et d'ordonnées

T = []
X = []
Y = []
for valeur in donnees[3:]:
    t=valeur[0]
    t=t.replace(',','.')
    t=t.replace('E','e')
    T.append(float(t))
    
    x=valeur[1]
    x=x.replace(',','.')
    x=x.replace('E','e')
    X.append(float(x))
    
    y=valeur[2]
    y=y.replace(',','.')
    y=y.replace('E','e')
    Y.append(float(y))
    
#############################################################
###                  PROGRAMME PRINCIPAL                  ###
#############################################################


# Demandes concernant l'échelle du tracé des forces et la masse du mobile

echelle = float(input("Quelle est l'échelle pour le tracé des forces ? (entre 0.1 et 0.5) "))
masse = float(input("Quelle est la masse du mobile (en kg) ? "))


# Création des listes des coordonnées et normes de la force de frottement

liste_Fx = []
liste_Fy = []
liste_F = []


# Calculs des vitesses, accélérations et force de frottement

for i in range (2, len(T)-2):
    
    " calculs des coordonnées de la vitesse au point i-1 "
    Vx1 = (X[i]-X[i-2])/(T[i]-T[i-2])
    Vy1 = (Y[i]-Y[i-2])/(T[i]-T[i-2])
    
    " calculs des coordonnées de la vitesse au point i+1 "
    Vx2 = (X[i+2]-X[i])/(T[i+2]-T[i])
    Vy2 = (Y[i+2]-Y[i])/(T[i+2]-T[i])

    " Calculs des coordonnées de l'accélération au point i "
    ax = (Vx2-Vx1)/(T[i+1]-T[i-1])
    ay = (Vy2-Vy1)/(T[i+1]-T[i-1])
    
    " Calculs des coordonnées de la somme des forces, c'est à dire de la force de frottement "
    Fx = masse*ax
    liste_Fx.append(Fx)
    Fy = masse*ay
    liste_Fy.append(Fy)

    " Calculs de la norme de la force de frottement "
    F = sqrt(Fx**2+Fy**2)
    liste_F.append(F)
 
 
# Traitement statistiques des mesures de la force de frottement

" Liste des 15 premiers coefficients de student pour un intervalle de confiance à 95% "
student_95 = [12.71, 4.30, 3.18, 2.78, 2.57, 2.45, 2.36, 2.31, 2.26, 2.23, 2.20, 2.18, 2.16, 2.14, 2.13]

" Calcul de la valeur moyenne de la norme de la force de frottement "
moyenne_F = sum(liste_F)/len(liste_F)

" Calcul de l'écart type "
somme_carre_ecart = 0
for k in range(0, len(liste_F)):
    somme_carre_ecart = somme_carre_ecart + (liste_F[k]-moyenne_F)**2
ecart_type = sqrt(somme_carre_ecart/(len(liste_F)-1))

" Calcul de l'incertitude type "
incertitude_type = student_95[len(liste_F)-1]*ecart_type/sqrt(len(liste_F))              


#######################################
#              Affichage              #
#######################################

" Affichage de la norme "
print("F = (",moyenne_F,"+-",incertitude_type,")N")

" Repère orthonormé "
plt.axis('equal')

" Affichage des points "
plt.plot(X,Y,'b+')

" Affichage des vecteurs frottement "
for j in range (0, len(liste_Fx)):
    plt.arrow(X[j+2], Y[j+2], echelle*liste_Fx[j], echelle*liste_Fy[j], head_width=0.01, head_length=0.01, fc='black', ec='black', length_includes_head=True)
    
plt.show()
